@@ -1,3 +1,8 @@
+import enum
+import functools
+import math
+import tomllib
+from importlib import resources
 from typing import *
 
 import click
@@ -5,39 +10,26 @@ import preparse
 
 __all__ = ["calculate", "main", "score"]
 
-_VALUES: dict = {
-    "A": 1.8,
-    "C": 2.5,
-    "D": -3.5,
-    "E": -3.5,
-    "F": 2.8,
-    "G": -0.4,
-    "H": -3.2,
-    "I": 4.5,
-    "K": -3.9,
-    "L": 3.8,
-    "M": 1.9,
-    "N": -3.5,
-    "P": -1.6,
-    "Q": -3.5,
-    "R": -4.5,
-    "S": -0.8,
-    "T": -0.7,
-    "V": 4.2,
-    "W": -0.9,
-    "X": None,
-    "Y": -1.3,
-    "-": None,
-}
+
+class Util(enum.Enum):
+    util = None
+
+    @functools.cached_property
+    def data(self: Self) -> dict:
+        "This cached property holds the cfg data."
+        text: str = resources.read_text("gravy.core", "cfg.toml")
+        ans: dict = tomllib.loads(text)
+        return ans
 
 
 def score(seq: Iterable) -> float:
     "This function calculates the GRAVY score."
     l: list = list()
     x: Any
+    y: Any
     for x in seq:
-        y = _VALUES[str(x)]
-        if y is not None:
+        y = Util.util.data["values"][str(x)]
+        if not math.isnan(y):
             l.append(y)
     if len(l):
         return sum(l) / len(l)
